@@ -1,5 +1,5 @@
-/**
- * Copyright (c) Facebook, Inc. and its affiliates.
+/*
+ * Copyright (c) Meta Platforms, Inc. and affiliates.
  *
  * This source code is licensed under the MIT license found in the
  * LICENSE file in the root directory of this source tree.
@@ -7,6 +7,7 @@
 
 #pragma once
 
+#include <faiss/impl/IDSelector.h>
 #include <faiss/impl/io.h>
 #include <faiss/invlists/InvertedLists.h>
 #include "Python.h"
@@ -43,3 +44,17 @@ struct PyCallbackIOReader : faiss::IOReader {
 
     ~PyCallbackIOReader() override;
 };
+
+/***********************************************************
+ * Callbacks for IDSelector
+ ***********************************************************/
+
+struct PyCallbackIDSelector : faiss::IDSelector {
+    PyObject* callback;
+
+    explicit PyCallbackIDSelector(PyObject* callback);
+
+    bool is_member(faiss::idx_t id) const override;
+
+    ~PyCallbackIDSelector() override;
+};
